import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:wordguessing/config/default_game_settings.dart';

class GameSettings {
  final String gameType;
  final String lang;

  GameSettings({
    required this.gameType,
    required this.lang,
  });

  static String getGameTypeValueFromUnsafe(String gameType) {
    if (DefaultGameSettings.allowedGameTypeValues.contains(gameType)) {
      return gameType;
    }

    return DefaultGameSettings.defaultGameTypeValue;
  }

  static String getLangValueFromUnsafe(String lang) {
    if (DefaultGameSettings.allowedLangValues.contains(lang)) {
      return lang;
    }

    return DefaultGameSettings.defaultLangValue;
  }

  factory GameSettings.createDefault() {
    return GameSettings(
      gameType: DefaultGameSettings.defaultGameTypeValue,
      lang: DefaultGameSettings.defaultLangValue,
    );
  }

  void dump() {
    printlog('$GameSettings:');
    printlog('  ${DefaultGameSettings.parameterCodeGameType}: $gameType');
    printlog('  ${DefaultGameSettings.parameterCodeLangValue}: $lang');
    printlog('');
  }

  @override
  String toString() {
    return '$GameSettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      DefaultGameSettings.parameterCodeGameType: gameType,
      DefaultGameSettings.parameterCodeLangValue: lang,
    };
  }
}
