import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:wordguessing/cubit/game_cubit.dart';
import 'package:wordguessing/models/game/game.dart';
import 'package:wordguessing/ui/widgets/indicators/score_indicator.dart';

class ScoreBarWidget extends StatelessWidget {
  const ScoreBarWidget({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        final int count = currentGame.questionsCount - 1;

        final String goodAnswersString = '👍 ${currentGame.goodAnswers}/$count';
        final String wrongAnswersString = '🚩 ${currentGame.wrongAnswers}/$count';

        return Container(
          padding: const EdgeInsets.all(5),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              ScoreIndicator(
                text: goodAnswersString,
                blockColor: Colors.green,
              ),
              const SizedBox(width: 20),
              ScoreIndicator(
                text: wrongAnswersString,
                blockColor: Colors.orange,
              ),
            ],
          ),
        );
      },
    );
  }
}
